export const routes = {
  main: '/',
  enrollment: '/enrollment',
  token: '/token',
  timeout: '/timeout',
  passwordReset: '/password-reset',
  openidCallback: '/openid/callback',
  openidMfa: '/openid/mfa',
  openidMfaCallback: '/openid/mfa/callback',
};
